/*
 * Copyright 2021 verit Informationssysteme GmbH, Europaallee 10,
 * 67657 Kaiserslautern, Germany, http://www.verit.de.
 *
 * All rights reserved.
 *
 * This product or document is protected by copyright and distributed
 * under licenses restricting its use, copying, distribution, and
 * decompilation. No part of this product or documentation may be
 * reproduced in any form by any means without prior written authorization
 * of verit Informationssysteme GmbH and its licensors, if any.
 */

import java.util.ArrayList;
import java.util.List;

import de.verit.klaros.core.model.KlarosTestCaseResult;
import de.verit.klaros.core.model.KlarosTestSuite;
import de.verit.klaros.core.model.KlarosTestSuiteResult;
import de.verit.klaros.scripting.KlarosContext;
import de.verit.klaros.scripting.KlarosScript;

/** The report tutorial example script. */
public class ReportTutorial implements KlarosScript {

    @Override
    public void execute(final KlarosContext context) {

        // Get the parameter value containing the name of the test suite
        final String suiteName = (String) context.getParameterValue("suiteName");
        KlarosTestSuite testSuite;

        // Build the query using the parameter
        String suiteQuery = "select suite from KlarosTestSuite suite where suite.name='" + suiteName + "'";
        if (context.getActiveProject() != null) {
            suiteQuery += " and suite.configuration.name='";
            suiteQuery += context.getActiveProject().getName();
            suiteQuery += "'";
        }

        // Execute the query using the parameter
        @SuppressWarnings("unchecked")
        final List<KlarosTestSuite> testSuites = (List<KlarosTestSuite>) context.executeQuery(suiteQuery);

        final List<KlarosTestCaseResult> success = new ArrayList<>();
        final List<KlarosTestCaseResult> error = new ArrayList<>();
        final List<KlarosTestCaseResult> failure = new ArrayList<>();
        final List<KlarosTestCaseResult> skipped = new ArrayList<>();

        // Add the first result to the render context - only one result is expected
        if (!testSuites.isEmpty()) {

            testSuite = testSuites.get(0);
            // prepare data for the pie chart
            // iterate over the results of every test suite execution
            for (final KlarosTestSuiteResult testSuiteResult : testSuite.getResults()) {
                // iterate over the results of every test case execution
                for (final KlarosTestCaseResult testCaseResult : testSuiteResult.getResults()) {
                    if (testCaseResult.isError()) {
                        error.add(testCaseResult);
                    } else if (testCaseResult.isFailure()) {
                        failure.add(testCaseResult);
                    } else if (testCaseResult.isPassed()) {
                        success.add(testCaseResult);
                    } else if (testCaseResult.isSkipped()) {
                        skipped.add(testCaseResult);
                    }
                }
            }
            context.add("testSuite", testSuite);
        }

        context.add("success", success);
        context.add("error", error);
        context.add("failure", failure);
        context.add("skipped", skipped);
    }
}
